@@ -190,7 +190,8 @@ class CloudFSRESTAdapter(object):
         if last_name:
             data['last_name'] = last_name
 
-        self._make_request('create account', data=data, oauth_request=True)
+        response = self._make_request('create account', data=data, oauth_request=True)
+        return response['result']
 
     def authenticate(self, username, password):
         """Authenticate to CloudFS using the provided user details.
@@ -207,7 +208,11 @@ class CloudFSRESTAdapter(object):
             'username':username,
             'password':password
         }
-        return self._make_request('get oauth token', data=data, oauth_request=True)
+        result = self._make_request('get oauth token', data=data, oauth_request=True)
+        if 'access_token' in result:
+            return True
+
+        return False
 
     def ping(self):
         """Check that authentication is still valid
@@ -844,9 +849,8 @@ class CloudFSConnection(object):
         result = self._request(path, method, data=data, params=params, oauth=True)
         if 'access_token' in result:
             self.auth_token = result['access_token']
-            return True
 
-        return False
+        return result
 
     def request(self, path, data={}, params={}, files=None, method='GET', response_processor=None, headers={}, background=False):
         default_headers = {'Authorization':'Bearer {}'.format(self.auth_token)}
@@ -866,7 +870,7 @@ class CloudFSConnection(object):
         if oauth:
             headers['Content-Type'] = 'application/x-www-form-urlencoded; charset="utf-8"'
         headers['Date'] = datetime.datetime.utcnow().strftime('%a, %d %b %Y %H:%M:%S GMT')
-        headers['User-Agent'] = 'CloudFSPythonSDK/0.80.1'
+        headers['User-Agent'] = 'CloudFSPythonSDK/0.80.2'
 
         return headers
 
